// This is a generated file, see extract.sh
const char * i18n[] = {
_("Aadhar number"),
_("AHV number"),
_("Albania"),
_("Asia"),
_("Belgium"),
_("Birthdate"),
_("Birth Number"),
_("Birthplace"),
_("Citizen Service Number"),
_("Code Insee"),
_("CPR-nummer"),
_("Czech Republic"),
_("Demoworld"),
_("Denmark"),
_("Europe"),
_("Fiscal code"),
_("France"),
_("Full name"),
_("Germany"),
_("Identity Number"),
_("India"),
_("Italy"),
_("Japan"),
_("My number"),
_("National Register Number"),
_("Netherlands"),
_("North America"),
_("Prime number"),
_("Slovakia"),
_("Social security number"),
_("Spain"),
_("Square number"),
_("Switzerland"),
_("Tax number"),
_("Taxpayer identification number"),
_("Testland"),
_("United States of America (USA)"),
};
